| brown_metadata | R Documentation |
This dataset provides metadata for the text files in the Brown family of corpora. It maps standardized file names to the textual categories genre and subgenre.
brown_metadata
brown_metadataA data frame with 500 rows and 3 columns:
Standardized name of the text file (e.g. "A01", "J58", "R07")
4 macro genres ("press", "general_prose", "learned", "fiction")
15 genres (e.g. "press_editorial", "popular_lore", "adventure_western_fiction"))
McEnery, Tony & Andrew Hardie. 2012. Corpus linguistics. Cambridge: Cambridge University Press.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.